pythonwhat
----------

For an introduction to SCTs and how they use pythonwhat, visit the `README <https://github.com/datacamp/pythonwhat>`_.

This documentation features:

- A glossary with typical use-cases and corresponding SCT constructs.
- Reference documentation of all actively maintained pythonwhat functions.
- A set of basic and advanced articles that gradually expose you to all of pythonwhat's functionality and best practices.

If you are new to writing SCTs for Python exercises, start with the tutorial and work your way through the other basic articles.
The glossary is good to get a quick overview of how all functions play together after you have a basic understanding.
The reference docs become useful when you grasp all concepts and want to look up details on how to call certain functions and specify custom feedback messages.

.. toctree::
   :maxdepth: 1
   :caption: Glossary

   glossary

.. toctree::
   :maxdepth: 2

   reference

.. toctree::
   :maxdepth: 1
   :caption: Basic articles

   articles/tutorial.rst
   articles/checking_function_calls.rst
   articles/make_your_sct_robust.rst
   articles/checking_through_string_matching.rst

.. toctree::
   :maxdepth: 1
   :caption: Advanced articles

   articles/checking_compound_statements.rst
   articles/expression_tests.rst
   articles/processes.rst
   articles/single_process_exercise.rst
   articles/electives.rst
   articles/test_to_check.rst

.. toctree::
   :maxdepth: 1
   :caption: Tests

   tests

For details, questions and suggestions, `contact us <mailto:content-engineering@datacamp.com>`_.
